@@ -1,7 +1,6 @@
 """Various with-statement context utilities."""
 
-from contextlib import AbstractContextManager, contextmanager
-from functools import wraps
+from contextlib import contextmanager
 from importlib import import_module
 from multiprocessing.connection import Pipe
 import errno
@@ -115,10 +114,9 @@ class SplitExec:
 
     def __enter__(self):
         parent_pipe, child_pipe = Pipe()
-        childpid = os.fork()
 
-        if childpid != 0:
-            self.childpid = childpid
+        if pid := os.fork():
+            self.childpid = pid
             self._parent_setup()
             self.__pipe = parent_pipe
             frame = self.__get_context_frame()
@@ -312,6 +310,35 @@ def syspath(path, condition=True, position=0):
         sys.path = syspath
 
 
+@contextmanager
+def os_environ(*remove, **update):
+    """Mangle the ``os.environ`` dictionary and revert on exit.
+
+    :param remove: variables to remove
+    :param update: variable -> value mapping to add or alter
+    """
+    env = os.environ
+    update = update or {}
+    remove = remove or []
+
+    # variables being updated or removed
+    changed = (set(update) | set(remove)) & set(env)
+    # variables to restore on exit
+    update_after = {k: env[k] for k in changed}
+    # variables to remove on exit
+    remove_after = frozenset(k for k in update if k not in env)
+
+    try:
+        env.update(update)
+        for k in remove:
+            env.pop(k, None)
+        yield
+    finally:
+        env.update(update_after)
+        for k in remove_after:
+            env.pop(k)
+
+
 # Ideas and code for the patch context manager have been borrowed from mock
 # (https://github.com/testing-cabal/mock) governed by the BSD-2 license found
 # below.
@@ -387,17 +414,3 @@ def patch(target, new):
         yield
     finally:
         setattr(obj, attr, orig_attr)
-
-
-# TODO: drop when >=py37 only
-class nullcontext(AbstractContextManager):
-    """Context manager that does no additional processing."""
-
-    def __init__(self, enter_result=None):
-        self.enter_result = enter_result
-
-    def __enter__(self):
-        return self.enter_result
-
-    def __exit__(self, *excinfo):
-        pass
